@@ -4,8 +4,8 @@ module Bundler
   # Represents metadata from when the Bundler gem was built.
   module BuildMetadata
     # begin ivars
-    @built_at = "2022-03-23".freeze
-    @git_commit_sha = "4bbb70e7de".freeze
+    @built_at = "2022-06-01".freeze
+    @git_commit_sha = "e7e41afd92".freeze
     @release = true
     # end ivars
 
@@ -29,7 +29,7 @@ module Bundler
 
       # If Bundler has been installed without its .git directory and without a
       # commit instance variable then we can't determine its commits SHA.
-      git_dir = File.join(File.expand_path("../../../..", __FILE__), ".git")
+      git_dir = File.expand_path("../../../.git", __dir__)
       if File.directory?(git_dir)
         return @git_commit_sha = Dir.chdir(git_dir) { `git rev-parse --short HEAD`.strip.freeze }
       end
